@@ -1,6 +1,6 @@
 package Getopt::Euclid;
 
-use version; $VERSION = qv('0.2.7');
+use version; $VERSION = qv('0.2.8');
 
 use warnings;
 use strict;
@@ -171,7 +171,8 @@ sub process_args {
         my $msg = join q{}, @msg;
         $msg =~ tr/\0\1/ \t/;
         $msg =~ s/\n?\z/\n/xms;
-        warn "$msg(Try: $SCRIPT_NAME --help)\n\n";
+        warn "$msg(Try this for usage help : $SCRIPT_NAME --help)\n".
+                 "(Try this for full manual: $SCRIPT_NAME --man )\n\n";
         exit 2;    # Traditional "bad arg list" value
     };
 
@@ -325,11 +326,11 @@ sub _process_prog_pod {
     my $VERS  = qr{ $HWS VERSION $HWS \n }xms;
     my $USAGE = qr{ $HWS USAGE   $HWS \n }xms;
 
-    my $STD = qr{ STANDARD | STD  }xms;
-    my $ARG = qr{ $HWS ARG(?:UMENT)?S? }xms;
+    my $STD = qr{ STANDARD | STD | PROGRAM | SCRIPT | CLI  | COMMAND(?:-|\s)?LINE }xms;
+    my $ARG = qr{ $HWS (?:PARAM(?:ETER)?|ARG(?:UMENT)?)S? }xms;
 
-    my $OPTIONS  = qr{ $HWS $STD? $HWS OPTION(?:AL|S)? $ARG? $HWS \n }xms;
-    my $REQUIRED = qr{ $HWS $STD? $HWS REQUIRED        $ARG? $HWS \n }xms;
+    my $OPTIONS  = qr{ $HWS $STD? $HWS OPTION(?:AL|S)?        $ARG? $HWS \n }xms;
+    my $REQUIRED = qr{ $HWS $STD? $HWS (?:REQUIRED|MANDATORY) $ARG? $HWS \n }xms;
 
     my $EUCLID_ARG = qr{ ^=item \s* ([^\n]*?) \s* \n\s*\n
                         (
@@ -529,7 +530,6 @@ sub _process_euclid_specs {
             $arg->{false_vals} = '(?:' . join( '|', @false_vals ) . ')';
         }
 
-
         while (
             $info =~ m{\G \s* (([^.]+)\.([^:=\s]+) \s*[:=]\s* ([^\n]*)) }gcxms )
         {
@@ -537,9 +537,8 @@ sub _process_euclid_specs {
 
             # Check for misplaced fields...
             if ( $arg->{name} !~ m{\Q<$var>}xms ) {
-                _fail(
-"Invalid constraint: $spec\n(No <$var> placeholder in argument: $arg->{name})"
-                );
+                _fail( "Invalid constraint: $spec\n(No <$var> placeholder in ".
+                    "argument: $arg->{name})" );
             }
 
             # Decode...
@@ -583,13 +582,22 @@ sub _process_euclid_specs {
                 }
 
             }
-            elsif ( $field eq 'default' ) {
+            elsif ( ($field eq 'default') || ($field eq 'opt_default') ) {
                 eval "\$val = $val; 1"
-                  or _fail("Invalid .default value: $spec\n($@)");
-                $arg->{var}{$var}{default} = $val;
-                $arg->{has_defaults} = exists $arg->{has_defaults} ?
-                                      $arg->{has_defaults}++ :
+                  or _fail("Invalid .$field value: $spec\n($@)");
+                $arg->{var}{$var}{$field} = $val;
+                my $has_field = 'has_'.$field;
+                $arg->{$has_field} = exists $arg->{$has_field} ?
+                                      $arg->{$has_field}++ :
                                       1;
+                # Optional defaults need optional placeholders
+                if ($field eq 'opt_default') {
+                    if ( $arg->{name} !~ m{\Q[<$var>]}xms ) {
+                       _fail( "Invalid .opt_default constraint: $spec\n(Placeholder".
+                           " <$var> has to be optional, i.e. [<$var>], to have ".
+                           "an optional default in argument: $arg->{name})" );
+                    }
+                }
             }
             elsif ( $field eq 'excludes.error' ) {
                 $arg->{var}{$var}{excludes_error} = $val;
@@ -599,7 +607,7 @@ sub _process_euclid_specs {
                 for my $excl_var (@{$arg->{var}{$var}{excludes}}) {
                     if ($var eq $excl_var) {
                         _fail( "Invalid .excludes value for variable <$var>: ".
-                            "<$excl_var> cannot exclude itself\n" );
+                            "<$excl_var> cannot exclude itself." );
                     }
                     $excluded_by{$excl_var} = $var;
                 }
@@ -770,9 +778,15 @@ sub _verify_args {
             for my $excl_var ( @{$var->{excluded_by}}, @{$var->{excludes}} ) {
                 if (exists $seen_vars{$excl_var}) {
                     delete $arg_specs_ref->{$arg_name}{var}{$var_name}{default};
-                    $arg_specs_ref->{$arg_name}{has_defaults}--;
-                    if ($arg_specs_ref->{$arg_name}{has_defaults} == 0) {
-                        delete $arg_specs_ref->{$arg_name}{has_defaults};
+                    $arg_specs_ref->{$arg_name}{has_default}--;
+                    delete $arg_specs_ref->{$arg_name}{var}{$var_name}{opt_default};
+                    $arg_specs_ref->{$arg_name}{has_opt_default}--;
+                   
+                    if ($arg_specs_ref->{$arg_name}{has_default} == 0) {
+                        delete $arg_specs_ref->{$arg_name}{has_default};
+                    }
+                    if ($arg_specs_ref->{$arg_name}{has_opt_default} == 0) {
+                        delete $arg_specs_ref->{$arg_name}{has_opt_default};
                     }
                 }
             }
@@ -785,10 +799,11 @@ sub _verify_args {
   ARG:
     for my $arg_name ( keys %{$arg_specs_ref} ) {
 
-        # Skip non-existent/non-defaulting arguments
+        # Skip non-existent/non-defaulting/non-optional-defaulting arguments
         next ARG
           if !exists $ARGV{$arg_name}
-              && !$arg_specs_ref->{$arg_name}{has_defaults};
+              && !(   $arg_specs_ref->{$arg_name}{has_default}
+                   || $arg_specs_ref->{$arg_name}{has_opt_default} );
 
         # Ensure all vars exist within arg...
         my @vars = keys %{$arg_specs_ref->{$arg_name}{placeholders}};
@@ -846,10 +861,12 @@ sub _verify_args {
 
                 # Assign placeholder defaults (if necessary)...
                 next ARG
-                  if !exists $arg_specs_ref->{$arg_name}{var}{$var}{default};
+                  if   !exists $arg_specs_ref->{$arg_name}{var}{$var}{default}
+                    && !exists $arg_specs_ref->{$arg_name}{var}{$var}{opt_default};
 
-                $entry->{$var} =
-                  $arg_specs_ref->{$arg_name}{var}{$var}{default};
+                $entry->{$var} = exists $arg_specs_ref->{$arg_name}{var}{$var}{opt_default} ?
+                                 $arg_specs_ref->{$arg_name}{var}{$var}{opt_default} :
+                                 $arg_specs_ref->{$arg_name}{var}{$var}{default};
             }
         }
 
@@ -894,7 +911,7 @@ sub _convert_to_regex {
         push @arg_variants, @{$args_ref->{$arg_name}->{variants}};
     }
     my $no_match = join('|',@arg_variants);
-    $no_match =~ s{([@#$^*()+{}?])}{\\$1}gxms; # Quotemeta specials
+####    $no_match =~ s{([@#$^*()+{}?])}{\\$1}gxms; # Quotemeta specials 
     $no_match = '(?!'.$no_match.')';
 
 
@@ -903,7 +920,7 @@ sub _convert_to_regex {
         my $regex = $arg_name;
 
         # Quotemeta specials...
-        $regex =~ s{([@#$^*()+{}?])}{\\$1}gxms;
+####        $regex =~ s{([@#$^*()+{}?])}{\\$1}gxms;
 
         $regex = "(?:$regex)";
 
@@ -1129,19 +1146,21 @@ sub _insert_default_values {
         for my $var_name (@var_names) {
             # Get default for this variable
             my $var = $args->{$item_name}->{var}->{$var_name};
-            my $var_default;
-            if (exists $var->{default}) {
-                if (ref($var->{default}) eq 'ARRAY') {
-                    $var_default = join(' ', @{$var->{default}});
-                } elsif (ref($var->{default}) eq '') {
-                    $var_default = $var->{default};
+            for my $default_type ( 'default', 'opt_default' ) {
+                my $var_default;
+                if (exists $var->{$default_type}) {
+                    if (ref($var->{$default_type}) eq 'ARRAY') {
+                        $var_default = join(' ', @{$var->{$default_type}});
+                    } elsif (ref($var->{$default_type}) eq '') {
+                        $var_default = $var->{$default_type};
+                    } else {
+                        carp "Getopt::Euclid found an unexpected default value type";
+                    }
                 } else {
-                    carp "Getopt::Euclid found an unexpected default value type";
+                    $var_default = 'none';
                 }
-            } else {
-                $var_default = 'none';
+                $item_spec =~ s/$var_name\.$default_type/$var_default/g;
             }
-            $item_spec =~ s/$var_name\.default/$var_default/g;
         }
         $pod_string .= $item_spec;
     }
@@ -1222,12 +1241,22 @@ This document describes Getopt::Euclid version 0.2.7
 
     =item  -l[[en][gth]] <l>
 
-    Length of simulation [default: 99]
+    Length of simulation. The default is l.default
 
     =for Euclid:
         l.type:    int > 0
         l.default: 99
 
+    =item --debug [<log_level>]
+
+    Set the log level. Default is log_level.default but if you provide --debug,
+    then it is log_level.opt_default.
+
+    =for Euclid:
+        log_level.type:        int
+        log_level.default:     0
+        log_level.opt_default: 1
+
     =item --version
 
     =item --usage
@@ -1470,7 +1499,7 @@ See L<Specifying arguments> for details of the specification syntax.
 
 The actual headings that Getopt::Euclid can recognize here are:
 
-    =head1 [STD|STANDARD] REQUIRED [ARG|ARGUMENT][S]
+    =head1 [STANDARD|STD|PROGRAM|SCRIPT|CLI|COMMAND[-| ]LINE] [REQUIRED|MANDATORY] [PARAM|PARAMETER|ARG|ARGUMENT][S]
 
 =item =head1 OPTIONS
 
@@ -1484,7 +1513,7 @@ but there is no requirement that it supply both, or either.
 
 The actual headings that Getopt::Euclid recognizes here are:
 
-    =head1 [STD|STANDARD] OPTION[AL|S] [ARG|ARGUMENT][S]
+    =head1 [STANDARD|STD|PROGRAM|SCRIPT|CLI|COMMAND[-| ]LINE] OPTION[AL|S] [PARAM|PARAMETER|ARG|ARGUMENT][S]
 
 =item =head1 COPYRIGHT
 
@@ -1894,7 +1923,6 @@ placeholder's value (just as in the type test itself).
 You can also specify a default value for any placeholders that aren't
 given values on the command-line (either because their argument isn't
 provided at all, or because the placeholder is optional within the argument).
-
 For example:
 
     =item -size <h>[x<w>]
@@ -1909,11 +1937,32 @@ This ensures that if no C<< <w> >> value is supplied:
 
     -size 20
 
-then C<$ARGV{'-size'}{'w'}> is set to 80.
+then C<$ARGV{'-size'}{'w'}> is set to 80. Likewise, of the C<-size> argument is
+omitted entirely, both C<$ARGV{'-size'}{'h'}> and C<$ARGV{'-size'}{'w'}> are set
+to their respective default values
+
+However, Getopt::Euclid also supports a second type of default, optional defaults,
+that apply only to optional placeholders.
+
+For example:
+
+    =item --debug [<log_level>]
+
+    Set the log level
+
+    =for Euclid:
+        log_level.type:        int
+        log_level.default:     0
+        log_level.opt_default: 1
+
+This ensures that if the option C<< --debug >> is not specified, then
+C<$ARGV{'--debug'}> is set to 0, the regular default. But if no C<< <log_level> >>
+value is supplied:
+
+    --debug
+    
+then C<$ARGV{'--debug'}> is set to 1, the optional default.
 
-Likewise, of the C<-size> argument is omitted entirely, both
-C<$ARGV{'-size'}{'h'}> and C<$ARGV{'-size'}{'w'}> are set to their
-respective default values.
 
 The default value can be any valid Perl compile-time expression:
 
@@ -2227,6 +2276,28 @@ instead of:
     =for Euclid
         curse.default: '*$@!&'
 
+=item Invalid .opt_default value: %s
+
+Same as previous diagnostic, but for optional defaults.
+
+=item Invalid .opt_default constraint
+
+You specified an optional default but the placeholder that it affects is not an
+optional optional placeholder, i.e. an optional default has no effect on it. For
+example:
+
+    =item  -l[[en][gth]] <l>
+
+    =for Euclid:
+        l.opt_default: 123
+
+instead of:
+
+    =item  -l[[en][gth]] [<l>]
+
+    =for Euclid:
+        l.opt_default: 123
+
 =item Invalid .excludes value for variable %s: <%s> does not exist
 
 You specified to exclude a variable that was not seen in the POD. Make sure
